remove_version

Function remove_version 

pub fn remove_version(version: &Version) -> Result<(), SvmError>
Removes the provided version of Solc from the machine.

Note: removing a version that is concurrently being installed or executed is inherently racy; this also removes the version’s install lock file, so an installation that is in progress at the same time can fail or reinstall the version.